
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvContext.h>

#define MAXCOUNT	50

// ---------------------------------------------

xvContext::xvContext()
{
	actionset=FALSE;
}

// ---------------------------------------------

xvContext::xvContext(String name, int argc, char **argv)
{
	init(name, argc, argv);
}

// ---------------------------------------------

xvContext::~xvContext()
{
}

// ---------------------------------------------

XtAppContext xvContext::GetContext()
{
	return(ContextContext);
}

// ---------------------------------------------

void xvContext::init(String name, int argc, char **argv)
{

	w=XtVaAppInitialize(&ContextContext, name, NULL, 0, &argc, argv, 
		NULL, NULL);
	actionset=FALSE;
	ContextDisplay=XtDisplay(w);
	flushcount=0;
}

// ---------------------------------------------

void xvContext::ServiceEvent()
{
	if (XtAppPending(ContextContext) != 0) {
		XtAppNextEvent(ContextContext, &ContextEvent);
		XtDispatchEvent(&ContextEvent);
		flushcount++;
		if (flushcount > MAXCOUNT) {
			flushcount=0;
			XFlush(ContextDisplay);
		}
	}
}

// -------------------------------------------

void xvContext::RegisterWorkProc(XtWorkProc proc, XtPointer cdata)
{
	wproc=XtAppAddWorkProc(ContextContext, proc, cdata);
}

// -------------------------------------------

void xvContext::UnregisterWorkProc()
{
	XtRemoveWorkProc(wproc);
}

// -------------------------------------------

void xvContext::AddAction(String acname, XtActionProc proc)
{
	XtActionsRec thisaction[]= {
		{acname, proc },
	};

	XtAppAddActions(ContextContext, thisaction, XtNumber(thisaction));
}

// -------------------------------------------

XtActionHookId xvContext::AddActionHook(XtActionHookProc proc, XtPointer clientdata)
{
	if (!actionset) {
		waction=XtAppAddActionHook(ContextContext, proc, clientdata);
		actionset=TRUE;
		return(waction);
	}
	else
		return((XtActionHookId) NULL);
}

// -------------------------------------------

void xvContext::RemoveActionHook()
{
	if (actionset) XtRemoveActionHook(waction);
	actionset=FALSE;
}

// -------------------------------------------

void xvContext::Error(String message)
{
	XtAppError(ContextContext, message);
}

// -------------------------------------------

void xvContext::ErrorMsg(String name, String etype, String eclass, String edefault, String *params,
			Cardinal *numpar)
{
	XtAppErrorMsg(ContextContext, name, etype, eclass, edefault, params, numpar);
}

// -------------------------------------------

